Crate bevy_mod_gba

Crate bevy_mod_gba 

Provides integration between agb and bevy.

Re-exports

pub use agb;

Modules

prelude
Recommended imports.

Structs

AgbDmaPlugin
Sets up the DMA subsystem.
AgbInputPlugin
Makes the state of the GameBoy Advance’s built in gamepad available using standard Bevy gamepad events. This plugin must be added alongside the InputPlugin.
AgbLogPlugin
Integrates logging with the MGBA emulator.
AgbPlugin
This plugin group will add all the default plugins for a Bevy application using agb.
AgbRenderPlugin
Sets up a rendering subsystem.
AgbRunnerPlugin
Sets up a runner for the Bevy application which waits for VBlank between calls to update.
AgbSavePlugin
Sets up a SaveManager using the provided [SaveType] if any.
AgbSoundPlugin
Sets up the sound sub-system.
AgbTimePlugin
Sets up timers 2 & 3 as resources. Uses Timer 2 to provide Instant with reliable timing information.
AgbUnpackPlugin
Unpacks the Gba data into an idiomatic form for Bevy.
BlendDist
Provides access to Blend.
ButtonController
Helper to make it easy to get the current state of the GBA’s buttons.
Channel
Provides access to the Nth audio channel.
DmaController
Manages access to the Game Boy Advance’s DMA
GameBoyGamepad
Marker Component for the Entity that represents the gamepad built into the GameBoy Advance.
Noise
Provides access to the noise generator. See play_sound.
SaveManager
Manages access to the Game Boy Advance cartridge’s save chip. Initialization is handled by AgbSavePlugin. See access and access_with_timer.
Sound
Manages access to the Game Boy Advance’s beeps and boops sound hardware as part of the original Game Boy’s sound chip (the DMG).
Sprite
Alternative to Bevy’s Sprite type.
SpriteHandle
Handle to a stored sprite.
SpriteHandles
Asset storage for sprites.
Timer
Provides a single timer.
Video
Controls access to the underlying video hardware.
WindowDist
Provides access to Windows.