Re-exports
pub use agb;
Modules
- prelude
- Recommended imports.
Structs
- AgbDma
Plugin - Sets up the DMA subsystem.
- AgbInput
Plugin - Makes the state of the GameBoy Advance’s built in gamepad available using
standard Bevy gamepad events.
This plugin must be added alongside the
InputPlugin. - AgbLog
Plugin - Integrates logging with the MGBA emulator.
- AgbPlugin
- This plugin group will add all the default plugins for a Bevy application using
agb. - AgbRender
Plugin - Sets up a rendering subsystem.
- AgbRunner
Plugin - Sets up a runner for the Bevy application which waits for VBlank
between calls to
update. - AgbSave
Plugin - Sets up a
SaveManagerusing the provided [SaveType] if any. - AgbSound
Plugin - Sets up the sound sub-system.
- AgbTime
Plugin - Sets up timers 2 & 3 as resources.
Uses
Timer 2to provideInstantwith reliable timing information. - AgbUnpack
Plugin - Unpacks the
Gbadata into an idiomatic form for Bevy. - Blend
Dist - Provides access to
Blend. - Button
Controller - Helper to make it easy to get the current state of the GBA’s buttons.
- Channel
- Provides access to the
Nth audio channel. - DmaController
- Manages access to the Game Boy Advance’s DMA
- Game
BoyGamepad - Marker
Componentfor theEntitythat represents the gamepad built into the GameBoy Advance. - Noise
- Provides access to the noise generator.
See
play_sound. - Save
Manager - Manages access to the Game Boy Advance cartridge’s save chip.
Initialization is handled by
AgbSavePlugin. Seeaccessandaccess_with_timer. - Sound
- Manages access to the Game Boy Advance’s beeps and boops sound hardware as part of the original Game Boy’s sound chip (the DMG).
- Sprite
- Alternative to Bevy’s
Spritetype. - Sprite
Handle - Handle to a stored sprite.
- Sprite
Handles - Asset storage for sprites.
- Timer
- Provides a single timer.
- Video
- Controls access to the underlying video hardware.
- Window
Dist - Provides access to
Windows.